#[non_exhaustive]pub enum OpenAIAllowedToolsMode {
Auto,
Required,
}Expand description
Whether an allowed-tools policy may call zero tools or must call at least one.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Auto
Let the model decide whether to call one of the allowed tools.
Required
Require at least one call from the allowed subset.